package com.fastbee.data.controller.gis;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.fastbee.common.annotation.Log;
import com.fastbee.common.core.controller.BaseController;
import com.fastbee.common.core.domain.AjaxResult;
import com.fastbee.common.enums.BusinessType;
import com.fastbee.ggroup.domain.GSiteInfo;
import com.fastbee.ggroup.service.IGSiteInfoService;
import com.fastbee.common.utils.poi.ExcelUtil;
import com.fastbee.common.core.page.TableDataInfo;

/**
 * 站点基础信息Controller
 *
 * @author kerwincui
 * @date 2024-10-10
 */
@RestController
@RequestMapping("/gis/site/info")
@Api(tags = "站点基础信息")
public class GSiteInfoController extends BaseController
{
    @Autowired
    private IGSiteInfoService gSiteInfoService;

/**
 * 查询站点基础信息列表
 */
@PreAuthorize("@ss.hasPermi('ggroup:info:list')")
@GetMapping("/list")
@ApiOperation("查询站点基础信息列表")
    public TableDataInfo list(GSiteInfo gSiteInfo)
    {
        startPage();
        List<GSiteInfo> list = gSiteInfoService.selectGSiteInfoList(gSiteInfo);
        return getDataTable(list);
    }

    /**
     * 导出站点基础信息列表
     */
    @ApiOperation("导出站点基础信息列表")
    @PreAuthorize("@ss.hasPermi('ggroup:info:export')")
    @PostMapping("/export")
    public void export(HttpServletResponse response, GSiteInfo gSiteInfo)
    {
        List<GSiteInfo> list = gSiteInfoService.selectGSiteInfoList(gSiteInfo);
        ExcelUtil<GSiteInfo> util = new ExcelUtil<GSiteInfo>(GSiteInfo.class);
        util.exportExcel(response, list, "站点基础信息数据");
    }

    /**
     * 获取站点基础信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('ggroup:info:query')")
    @GetMapping(value = "/{siteId}")
    @ApiOperation("获取站点基础信息详细信息")
    public AjaxResult getInfo(@PathVariable("siteId") Long siteId)
    {
        return AjaxResult.success(gSiteInfoService.selectGSiteInfoById(siteId));
    }

    /**
     * 新增站点基础信息
     */
    @PreAuthorize("@ss.hasPermi('ggroup:info:add')")
    @PostMapping
    @ApiOperation("新增站点基础信息")
    public AjaxResult add(@RequestBody GSiteInfo gSiteInfo)
    {
        return toAjax(gSiteInfoService.insertGSiteInfo(gSiteInfo));
    }

    /**
     * 修改站点基础信息
     */
    @PreAuthorize("@ss.hasPermi('ggroup:info:edit')")
    @PutMapping
    @ApiOperation("修改站点基础信息")
    public AjaxResult edit(@RequestBody GSiteInfo gSiteInfo)
    {
        return toAjax(gSiteInfoService.updateGSiteInfo(gSiteInfo));
    }

    /**
     * 删除站点基础信息
     */
    @PreAuthorize("@ss.hasPermi('ggroup:info:remove')")
    @DeleteMapping("/{ids}")
    @ApiOperation("删除站点基础信息")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(gSiteInfoService.deleteGSiteInfoByIds(ids));
    }
}
