package com.fastbee.ggroup.service.impl;

import java.util.List;
import java.util.Objects;

import com.fastbee.common.exception.ServiceException;
import com.fastbee.common.utils.DateUtils;
import com.fastbee.common.utils.ValidationUtils;
import com.fastbee.ggroup.domain.GSites;
import com.fastbee.ggroup.mapper.GSitesMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fastbee.ggroup.mapper.GSiteInfoMapper;
import com.fastbee.ggroup.domain.GSiteInfo;
import com.fastbee.ggroup.service.IGSiteInfoService;

/**
 * 站点基础信息Service业务层处理
 * 
 * @author kerwincui
 * @date 2024-10-10
 */
@Service
public class GSiteInfoServiceImpl implements IGSiteInfoService 
{
    @Autowired
    private GSiteInfoMapper gSiteInfoMapper;


    /**
     * 查询站点基础信息
     * 
     * @param id 站点基础信息主键
     * @return 站点基础信息
     */
    @Override
    public GSiteInfo selectGSiteInfoById(Long id)
    {
        return gSiteInfoMapper.selectGSiteInfoById(id);
    }

    /**
     * 查询站点基础信息列表
     * 
     * @param gSiteInfo 站点基础信息
     * @return 站点基础信息
     */
    @Override
    public List<GSiteInfo> selectGSiteInfoList(GSiteInfo gSiteInfo)
    {
        return gSiteInfoMapper.selectGSiteInfoList(gSiteInfo);
    }

    /**
     * 新增站点基础信息
     * 
     * @param gSiteInfo 站点基础信息
     * @return 结果
     */
    @Override
    public int insertGSiteInfo(GSiteInfo gSiteInfo)
    {
        gSiteInfo.setCreateTime(DateUtils.getNowDate());
        return gSiteInfoMapper.insertGSiteInfo(gSiteInfo);
    }

    /**
     * 修改站点基础信息
     * 
     * @param gSiteInfo 站点基础信息
     * @return 结果
     */
    @Override
    public int updateGSiteInfo(GSiteInfo gSiteInfo)
    {
        //参数校验
        if(Objects.isNull(gSiteInfo.getSiteId())){
            throw new ServiceException("站点ID(siteId)字段不能为空！");
        }
        if(!ValidationUtils.isMobile(gSiteInfo.getManagerPhone())){
            throw new ServiceException("站点管理员手机号(managerPhone)格式不正确！");
        }
        //检查是否有该条数据
        if(Objects.isNull(gSiteInfoMapper.selectGSiteInfoById(gSiteInfo.getSiteId()))){
            //没有该条数据，则新增
            gSiteInfo.setCreateTime(DateUtils.getNowDate());
            return insertGSiteInfo(gSiteInfo);
        }
        gSiteInfo.setUpdateTime(DateUtils.getNowDate());
        return gSiteInfoMapper.updateGSiteInfo(gSiteInfo);
    }

    /**
     * 批量删除站点基础信息
     * 
     * @param ids 需要删除的站点基础信息主键
     * @return 结果
     */
    @Override
    public int deleteGSiteInfoByIds(Long[] ids)
    {
        return gSiteInfoMapper.deleteGSiteInfoByIds(ids);
    }

    /**
     * 删除站点基础信息信息
     * 
     * @param id 站点基础信息主键
     * @return 结果
     */
    @Override
    public int deleteGSiteInfoById(Long id)
    {
        return gSiteInfoMapper.deleteGSiteInfoById(id);
    }
}
